@@ -16,23 +16,27 @@ simple_rec <- recipe(mpg ~ ., data = mtcars)
 form <- mpg ~ .
 
 spline_rec <-
-  recipe(mpg ~ ., data = mtcars) %>%
-  step_normalize(all_predictors()) %>%
+  recipe(mpg ~ ., data = mtcars) |>
+  step_normalize(all_predictors()) |>
   step_bs(disp, deg_free = tune())
 
-lm_mod <- linear_reg() %>% set_engine("lm")
+lm_mod <- linear_reg() |> set_engine("lm")
 
 knn_mod <-
-  nearest_neighbor(mode = "regression", neighbors = tune()) %>%
+  nearest_neighbor(mode = "regression", neighbors = tune()) |>
   set_engine("kknn")
 
 knn_mod_two <-
-  nearest_neighbor(mode = "regression", neighbors = tune("K"), weight_func = tune()) %>%
+  nearest_neighbor(
+    mode = "regression",
+    neighbors = tune("K"),
+    weight_func = tune()
+  ) |>
   set_engine("kknn")
 
-get_coefs  <- function(x) {
-  x %>%
-    extract_fit_parsnip() %>%
+get_coefs <- function(x) {
+  x |>
+    extract_fit_parsnip() |>
     tidy()
 }
 
@@ -43,27 +47,25 @@ b_ctrl <- control_bayes(verbose = verb, save_pred = TRUE, extract = get_coefs)
 # ------------------------------------------------------------------------------
 
 mt_spln_lm <-
-  workflow() %>%
-  add_recipe(spline_rec) %>%
+  workflow() |>
+  add_recipe(spline_rec) |>
   add_model(lm_mod)
 
 mt_spln_knn <-
-  workflow() %>%
-  add_recipe(spline_rec) %>%
+  workflow() |>
+  add_recipe(spline_rec) |>
   add_model(knn_mod)
 
 mt_knn <-
-  workflow() %>%
-  add_recipe(simple_rec) %>%
+  workflow() |>
+  add_recipe(simple_rec) |>
   add_model(knn_mod)
 
 # ------------------------------------------------------------------------------
 
 set.seed(8825)
 mt_spln_lm_grid <-
-  tune_grid(mt_spln_lm,
-            resamples = folds,
-            control = g_ctrl)
+  tune_grid(mt_spln_lm, resamples = folds, control = g_ctrl)
 
 set.seed(8825)
 mt_spln_lm_bo <-
@@ -87,18 +89,17 @@ mt_spln_knn_grid <-
 
 set.seed(8825)
 mt_spln_knn_bo <-
-  tune_bayes(mt_spln_knn,
-             resamples = folds,
-             iter = 3,
-             control = b_ctrl)
+  tune_bayes(mt_spln_knn, resamples = folds, iter = 3, control = b_ctrl)
 
 set.seed(8825)
 mt_spln_knn_bo_sep <-
-  tune_bayes(knn_mod_two,
-             spline_rec,
-             resamples = folds,
-             iter = 3,
-             control = b_ctrl)
+  tune_bayes(
+    knn_mod_two,
+    spline_rec,
+    resamples = folds,
+    iter = 3,
+    control = b_ctrl
+  )
 
 # ------------------------------------------------------------------------------
 
@@ -107,10 +108,7 @@ mt_knn_grid <- tune_grid(mt_knn, resamples = folds, control = g_ctrl)
 
 set.seed(8825)
 mt_knn_bo <-
-  tune_bayes(mt_knn,
-             resamples = folds,
-             iter = 3,
-             control = b_ctrl)
+  tune_bayes(mt_knn, resamples = folds, iter = 3, control = b_ctrl)
 
 # ------------------------------------------------------------------------------
 
@@ -130,7 +128,7 @@ set.seed(7898)
 data_folds <- vfold_cv(two_class_dat, repeats = 5)
 
 two_class_rec <-
-  recipe(Class ~ ., data = two_class_dat) %>%
+  recipe(Class ~ ., data = two_class_dat) |>
   step_normalize(A, B)
 
 knn_model <-
@@ -139,22 +137,22 @@ knn_model <-
     neighbors = tune("K"),
     weight_func = tune(),
     dist_power = tune("exponent")
-  ) %>%
+  ) |>
   set_engine("kknn")
 
 two_class_wflow <-
-  workflow() %>%
-  add_recipe(two_class_rec) %>%
+  workflow() |>
+  add_recipe(two_class_rec) |>
   add_model(knn_model)
 
 two_class_set <-
-  extract_parameter_set_dials(two_class_wflow) %>%
-  update(K = neighbors(c(1, 50))) %>%
+  extract_parameter_set_dials(two_class_wflow) |>
+  update(K = neighbors(c(1, 50))) |>
   update(exponent = dist_power(c(1 / 10, 2)))
 
 set.seed(2494)
 two_class_grid <-
-  two_class_set %>%
+  two_class_set |>
   grid_max_entropy(size = 10)
 
 class_metrics <- metric_set(roc_auc, accuracy, kap, mcc)
@@ -171,10 +169,11 @@ knn_results <-
 knn_set <- two_class_set
 
 knn_gp <-
-  tune:::fit_gp(dat = collect_metrics(knn_results),
-                pset = knn_set,
-                metric = "accuracy",
-                control = control_bayes()
+  tune:::fit_gp(
+    dat = collect_metrics(knn_results),
+    pset = knn_set,
+    metric = "accuracy",
+    control = control_bayes()
   )
 
 saveRDS(
@@ -221,21 +220,21 @@ svm_model <-
     cost = tune(),
     degree = tune("%^*#"),
     scale_factor = tune()
-  ) %>%
+  ) |>
   set_engine("kernlab")
 
 two_class_wflow <-
-  workflow() %>%
-  add_recipe(two_class_rec) %>%
+  workflow() |>
+  add_recipe(two_class_rec) |>
   add_model(svm_model)
 
 two_class_set <-
-  extract_parameter_set_dials(two_class_wflow) %>%
+  extract_parameter_set_dials(two_class_wflow) |>
   update(cost = cost(c(-10, 4)))
 
 set.seed(2494)
 two_class_grid <-
-  two_class_set %>%
+  two_class_set |>
   grid_max_entropy(size = 5)
 
 class_only <- metric_set(accuracy, kap, mcc)
@@ -257,7 +256,7 @@ saveRDS(
 )
 
 two_class_reg_grid <-
-  two_class_set %>%
+  two_class_set |>
   grid_regular(levels = c(5, 4, 2))
 
 svm_reg_results <-
@@ -285,37 +284,36 @@ data_folds <- vfold_cv(mtcars, repeats = 2)
 # "rcv_results" used in test-autoplot.R, test-select_best.R, and test-estimate.R
 
 base_rec <-
-  recipe(mpg ~ ., data = mtcars) %>%
+  recipe(mpg ~ ., data = mtcars) |>
   step_normalize(all_predictors())
 
 disp_rec <-
-  base_rec %>%
-  step_bs(disp, degree = tune(), deg_free = tune()) %>%
+  base_rec |>
+  step_bs(disp, degree = tune(), deg_free = tune()) |>
   step_bs(wt, degree = tune("wt degree"), deg_free = tune("wt df"))
 
 lm_model <-
-  linear_reg(mode = "regression") %>%
+  linear_reg(mode = "regression") |>
   set_engine("lm")
 
 cars_wflow <-
-  workflow() %>%
-  add_recipe(disp_rec) %>%
+  workflow() |>
+  add_recipe(disp_rec) |>
   add_model(lm_model)
 
 cars_set <-
-  cars_wflow %>%
-  parameters %>%
-  update(degree = degree_int(1:2)) %>%
-  update(deg_free = deg_free(c(2, 10))) %>%
-  update(`wt degree` = degree_int(1:2)) %>%
+  cars_wflow |>
+  extract_parameter_set_dials() |>
+  update(degree = degree_int(1:2)) |>
+  update(deg_free = deg_free(c(2, 10))) |>
+  update(`wt degree` = degree_int(1:2)) |>
   update(`wt df` = deg_free(c(2, 10)))
 
 set.seed(255)
 cars_grid <-
-  cars_set %>%
+  cars_set |>
   grid_regular(levels = c(3, 2, 3, 2))
 
-
 rcv_results <-
   tune_grid(
     cars_wflow,
@@ -341,7 +339,7 @@ folds <- vfold_cv(mtcars, v = 3)
 
 rec <- recipe(mpg ~ ., data = mtcars)
 
-mod <- linear_reg() %>%
+mod <- linear_reg() |>
   set_engine("lm")
 
 lm_resamples <- fit_resamples(mod, rec, folds)
@@ -361,15 +359,15 @@ saveRDS(
 set.seed(7898)
 folds <- vfold_cv(mtcars, v = 2)
 
-rec <- recipe(mpg ~ ., data = mtcars) %>%
-  step_normalize(all_predictors()) %>%
+rec <- recipe(mpg ~ ., data = mtcars) |>
+  step_normalize(all_predictors()) |>
   step_ns(disp, deg_free = tune())
 
-mod <- linear_reg(mode = "regression") %>%
+mod <- linear_reg(mode = "regression") |>
   set_engine("lm")
 
-wflow <- workflow() %>%
-  add_recipe(rec) %>%
+wflow <- workflow() |>
+  add_recipe(rec) |>
   add_model(mod)
 
 set.seed(2934)
@@ -386,8 +384,8 @@ saveRDS(
 # A single survival model
 
 set.seed(1)
-sim_dat <- prodlim::SimSurv(200) %>%
-  mutate(event_time = Surv(time, event)) %>%
+sim_dat <- prodlim::SimSurv(200) |>
+  mutate(event_time = Surv(time, event)) |>
   select(event_time, X1, X2)
 
 set.seed(2)
@@ -396,8 +394,8 @@ sim_rs <- vfold_cv(sim_dat)
 time_points <- c(10, 1, 5, 15)
 
 boost_spec <-
-  boost_tree(trees = tune()) %>%
-  set_mode("censored regression") %>%
+  boost_tree(trees = tune()) |>
+  set_mode("censored regression") |>
   set_engine("mboost")
 
 srv_mtr <-
@@ -410,11 +408,11 @@ srv_mtr <-
 
 set.seed(2193)
 surv_boost_tree_res <-
-  boost_spec %>%
+  boost_spec |>
   tune_grid(
     event_time ~ X1 + X2,
     resamples = sim_rs,
-    grid  = tibble(trees = c(1, 5, 10, 20, 100)),
+    grid = tibble(trees = c(1, 5, 10, 20, 100)),
     metrics = srv_mtr,
     eval_time = time_points
   )
